``eradiate.experiments``
========================

.. automodule:: eradiate.experiments

.. py:currentmodule:: eradiate.experiments

Concrete classes
----------------

.. autosummary::
   :toctree: generated/autosummary/

   AtmosphereExperiment
   CanopyExperiment
   CanopyAtmosphereExperiment
   DEMExperiment

Interfaces
----------

.. autosummary::
   :toctree: generated/autosummary/

   Experiment
   EarthObservationExperiment

Functions
---------

.. autosummary::
   :toctree: generated/autosummary/

   run
